@@ -464,6 +464,8 @@ resizer.onResize = function ()
 		
 		$("#FrontPageManagerRight").after($("#FrontPageManagerLeft"))
 	}
+	
+	$('.carousel').resizeCarousel();
 }
 
 // Test for nth-child(...n) support
@@ -531,8 +533,15 @@ Arnolfini.frontPageColors = function ()
 	}
 }
 
+Arnolfini.carouselFix = function ()
+{
+	$("#MainContent .carousel").css('visibility', 'visible');
+	$("#MainContent").css("background-image", "none");
+}
+
 $(document).ready(function() {
 	$('#portal-globalnav li a').removeAttr('title');
+	setTimeout(Arnolfini.carouselFix, 1000);
 	Arnolfini.frontPageColors();
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
